==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/bean/SupplierinformationEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 供应商账号信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_supplierInformation")
public class SupplierinformationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="suppliermanage_id")
    private Long suppliermanageId; // 供应商管理档案主键
    @TableField(value="suppliermanage_name")
    private String suppliermanageName; // 供应商管理档案名称
    @TableField(value="org_id")
    private Long orgId; // 可发货组织主键
    @TableField(value="org_name")
    private String orgName; // 可发货组织名称
    @TableField(value="username")
    private String username; // 用户名
    @TableField(value="password")
    private String password; // 密码
    @TableField(value="openID")
    private String openid; // 微信ID
    @TableField(value="contact_id")
    private Long contactId; // 联系人主键
    @TableField(value="contact_phone")
    private String contactPhone; // 联系人电各方面
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    
    
    

    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public Long getSuppliermanageId() {
        return suppliermanageId;
    }

    public void setSuppliermanageId(Long suppliermanageId) {
        this.suppliermanageId = suppliermanageId;
    }
    public String getSuppliermanageName() {
        return suppliermanageName;
    }

    public void setSuppliermanageName(String suppliermanageName) {
        this.suppliermanageName = suppliermanageName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }
    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
    public String getOpenid() {
        return openid;
    }

    public void setOpenid(String openid) {
        this.openid = openid;
    }
    public Long getContactId() {
        return contactId;
    }

    public void setContactId(Long contactId) {
        this.contactId = contactId;
    }
    public String getContactPhone() {
        return contactPhone;
    }

    public void setContactPhone(String contactPhone) {
        this.contactPhone = contactPhone;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220613.033944-112-sources.jar: com/ejianc/business/purchasingmanagement/bean/SupplierinformationEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 供应商账号信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_supplierInformation")
public class SupplierinformationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="suppliermanage_id")
    private Long suppliermanageId; // 供应商管理档案主键
    @TableField(value="suppliermanage_name")
    private String suppliermanageName; // 供应商管理档案名称
    @TableField(value="org_id")
    private Long orgId; // 可发货组织主键
    @TableField(value="org_name")
    private String orgName; // 可发货组织名称
    @TableField(value="username")
    private String username; // 用户名
    @TableField(value="password")
    private String password; // 密码
    @TableField(value="openID")
    private String openid; // 微信ID
    @TableField(value="contact_phone")
    private String contactPhone; // 联系人电各方面
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="contact_name")
    private String contactName; // 联系人

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public Long getSuppliermanageId() {
        return suppliermanageId;
    }

    public void setSuppliermanageId(Long suppliermanageId) {
        this.suppliermanageId = suppliermanageId;
    }
    public String getSuppliermanageName() {
        return suppliermanageName;
    }

    public void setSuppliermanageName(String suppliermanageName) {
        this.suppliermanageName = suppliermanageName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }
    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
    public String getOpenid() {
        return openid;
    }

    public void setOpenid(String openid) {
        this.openid = openid;
    }
    public String getContactPhone() {
        return contactPhone;
    }

    public void setContactPhone(String contactPhone) {
        this.contactPhone = contactPhone;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
